@@ -28,8 +28,6 @@ class QColor;
 namespace Analitza {
 class Variables;
 class FunctionGraph;
-class PlotsModel;
-class PlotItem;
 
 class ANALITZAPLOT_EXPORT PlotBuilder
 {
@@ -40,7 +38,7 @@ class ANALITZAPLOT_EXPORT PlotBuilder
         FunctionGraph* create(const QColor& color, const QString& name) const;
         Analitza::Expression expression() const;
         QString display() const;
-        Variables* m_vars;
+        QSharedPointer<Variables> m_vars;
 
     protected:
         PlotBuilder();
@@ -58,11 +56,11 @@ class ANALITZAPLOT_EXPORT PlotsFactory
         virtual ~PlotsFactory();
         
         static PlotsFactory* self();
-        PlotBuilder requestPlot(const Analitza::Expression& expresssion, Dimension dim, Variables* vars = 0) const;
+        PlotBuilder requestPlot(const Analitza::Expression& expresssion, Dimension dim, const QSharedPointer<Variables> &vars = {}) const;
         QStringList examples(Dimensions s) const;
 
     private:
-        Variables* m_vars;
+        QSharedPointer<Variables> m_vars;
 };
 
 }
